package org.rcisoft.core.entity;


import com.fasterxml.jackson.annotation.JsonFormat;
import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.NoArgsConstructor;
import org.rcisoft.core.anno.OperateFlagAnno;
import org.rcisoft.core.constant.DelStatus;
import org.rcisoft.core.constant.FlagStatus;
import org.springframework.format.annotation.DateTimeFormat;

import javax.persistence.MappedSuperclass;
import java.io.Serializable;
import java.util.Date;

/**
 * Created with family.
 * author: cy
 * Date: 16/6/23
 * Time: 上午10:04
 * description: data 实体  常用属性
 */
@Data
@NoArgsConstructor
@AllArgsConstructor
@MappedSuperclass
public abstract class DataEntity<T>  implements Serializable {
    private static final long serialVersionUID = 1L;

    protected String remarks;	// 备注
    protected String createBy;	// 创建者
    @DateTimeFormat(pattern="yyyy/MM/dd HH:mm:ss")
    @JsonFormat(timezone = "GMT+8",pattern = "yyyy/MM/dd HH:mm")
    protected Date createDate;// 创建日期

    @OperateFlagAnno
    protected String updateBy;	// 更新者

    @OperateFlagAnno(jdbcTypeName = "TIMESTAMP")
    @DateTimeFormat(pattern="yyyy/MM/dd HH:mm:ss")
    @JsonFormat(timezone = "GMT+8",pattern = "yyyy/MM/dd HH:mm")
    protected Date updateDate;// 更新日期

    @OperateFlagAnno
    protected String delFlag ; // 删除标记（0：正常；1：删除；2：审核）

    @OperateFlagAnno
    protected String flag ; // 启用标记（0：停用；1：启用）

    // @OperateFlagAnno
    protected String corpId ; // 企业id

    /**
     * 设置删除
     */
    public void setDeleted(){
        this.setDelFlag(DelStatus.DELETED.getStatus());
    }

    /**
     * 设置非删除
     */
    public void setNotDeleted(){
        this.setDelFlag(DelStatus.NORMAL.getStatus());
    }


    /**
     * 设置启用
     */
    public void setStart(){
        this.setFlag(FlagStatus.NORMAL.getStatus());
    }

    /**
     * 设置停用
     */
    public void setStop(){
        this.setFlag(FlagStatus.ABNORMAL.getStatus());
    }

    /**
     * 设置非删除&启用
     */
    public void setNormal(){
        this.setFlag(FlagStatus.NORMAL.getStatus());
        this.setDelFlag(DelStatus.NORMAL.getStatus());
    }


}
