package org.rcisoft.core.result;

import com.google.common.base.MoreObjects;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import org.rcisoft.core.util.UserUtil;
import org.springframework.core.annotation.Order;

import java.io.Serializable;

/**
 * 返回信息
 *
 * @author David
 */
@ApiModel(value = "请求响应")
public class Ret<T> implements Serializable {
    @Order(1)
    @ApiModelProperty(value = "错误码")
    private String code;

    @Order(2)
    @ApiModelProperty(value = "错误描述")
    private String msg;

    @Order(3)
    @ApiModelProperty(value = "请求时间")
    private Long ctime;

    @Order(4)
    @ApiModelProperty(value = "请求编号")
    private String requestID;

    @Order(5)
    @ApiModelProperty(value = "响应数据")
    private T data;

    public Ret() {
        this(null);
    }

    public Ret(String code) {
        this(code, null);
    }

    public Ret(String code, String msg) {
        this.code = code;
        this.msg = msg;
        this.ctime = System.currentTimeMillis();
        if (UserUtil.getCurUser() != null) {
            this.requestID = String.valueOf(UserUtil.getCurUser().getRequireId());
        }
    }

    //构建成功返回
    public static Ret ok() {
        return new Ret(ResultCode.SUCCESS.getCode().toString(), "ok");
    }

    //构建系统异常返回
    public static Ret error() {
        return new Ret(ResultCode.ERROR.getCode().toString(), "false");
    }


    public String getCode() {
        return code;
    }

    public Ret<T> setCode(String code) {
        this.code = code;
        return this;
    }

    public String getMsg() {
        return msg;
    }

    public Ret<T> setMsg(String msg) {
        this.msg = msg;
        return this;
    }

    public Long getCtime() {
        return ctime;
    }

    public Ret<T> setCtime(Long ctime) {
        this.ctime = ctime;
        return this;
    }

    public String getRequestID() {
        return requestID;
    }

    public Ret<T> setRequestID(String requestID) {
        this.requestID = requestID;
        return this;
    }

    public T getData() {
        return data;
    }

    public Ret<T> setData(T data) {
        this.data = data;
        return this;
    }

    @Override
    public String toString() {
        return MoreObjects.toStringHelper(this)
                .add("\ncode", code)
                .add("\nmsg", msg)
                .add("\nctime", ctime)
                .add("\nrequestID", requestID)
                .add("\ndata", data)
                .toString();
    }

}

